@@ -1,14 +1,15 @@
 import sqlalchemy as sa
 from .manager import VersioningManager
 from .operation import Operation
-from .utils import changeset
+from .utils import changeset, vacuum
 
 
-__version__ = '0.9.0'
+__version__ = '0.10.1'
 
 
 __all__ = (
     changeset,
+    vacuum,
     Operation,
     VersioningManager
 )
@@ -20,7 +21,8 @@ versioning_manager = VersioningManager()
 def make_versioned(
     mapper=sa.orm.mapper,
     session=sa.orm.session.Session,
-    manager=versioning_manager
+    manager=versioning_manager,
+    options={}
 ):
     """
     This is the public API function of SQLAlchemy-Continuum for making certain
@@ -40,6 +42,7 @@ def make_versioned(
     uow = manager.uow
     uow.track_operations(mapper)
     uow.track_session(session)
+    manager.options.update(options)
 
     sa.event.listen(
         sa.engine.Engine,
