@@ -2,9 +2,9 @@ import re
 from collections import OrderedDict
 from functools import wraps
 import sqlalchemy as sa
-from sqlalchemy_utils.functions import identity
+from sqlalchemy_utils.functions import identity, has_changes
 from .operation import Operation
-from .utils import is_versioned, is_modified, has_changes
+from .utils import is_versioned, is_modified
 
 
 def tracked_operation(func):
@@ -138,9 +138,48 @@ class UnitOfWork(object):
             version_obj.operation_type = value['operation_type']
             self.assign_attributes(value['target'], version_obj)
 
-            version_obj.transaction_id = (
+            setattr(
+                version_obj,
+                self.manager.option(
+                    value['target'],
+                    'transaction_column_name'
+                ),
                 self.current_transaction_id
             )
+            self.update_version_validity(value['target'], version_obj)
+
+    def update_version_validity(self, parent, version_obj):
+        """
+        Updates previous version object end_transaction_id based on given
+        parent object and newly created version object.
+
+        This method is only used when using 'validity' versioning strategy.
+
+        :param parent: SQLAlchemy declarative parent object
+        :parem version_obj: SQLAlchemy declarative version object
+        """
+        if (
+            self.manager.option(parent, 'strategy') ==
+            'validity'
+        ):
+            fetcher = self.manager.fetcher(parent)
+            session = sa.orm.object_session(version_obj)
+            return (
+                session.query(version_obj.__class__)
+                .filter(
+                    sa.and_(
+                        version_obj.__class__.transaction_id ==
+                        fetcher._transaction_id_subquery(
+                            version_obj, next_or_prev='prev'
+                        ),
+                        *fetcher._pk_correlation_condition(version_obj)
+                    )
+                )
+                .update(
+                    {'end_transaction_id': self.current_transaction_id},
+                    synchronize_session=False
+                )
+            )
 
     def create_association_versions(self, session):
         """
@@ -378,6 +417,31 @@ class UnitOfWork(object):
             return parameters
         return params
 
+    def should_nullify_attr(self, version_obj, attr):
+        """
+        Returns whether or not given attribute of given version object should
+        be nullified (set to None) at the end of the transaction.
+
+        :param version_obj:
+            Version object to check the attribute nullification
+        :paremt attr:
+            SQLAlchemy InstrumentedAttribute object
+        """
+        parent = version_obj.__parent_class__
+        return (
+            not self.manager.option(
+                parent,
+                'store_data_at_delete'
+            ) and
+            version_obj.operation_type == Operation.DELETE and
+            attr.property.columns[0].primary_key is not True and
+            attr.key !=
+            self.manager.option(
+                parent,
+                'transaction_column_name'
+            )
+        )
+
     def assign_attributes(self, parent_obj, version_obj):
         """
         Assigns attributes values from parent object to version object. If the
@@ -394,9 +458,7 @@ class UnitOfWork(object):
             if attr_name in excluded_attributes:
                 continue
             if isinstance(attr.property, sa.orm.ColumnProperty):
-                if (version_obj.operation_type == Operation.DELETE and
-                        attr.property.columns[0].primary_key is not True
-                        and attr_name != 'transaction_id'):
+                if self.should_nullify_attr(version_obj, attr):
                     value = None
                 else:
                     value = getattr(parent_obj, attr_name)
