@@ -1,6 +1,8 @@
+from collections import defaultdict
 import itertools
 import sqlalchemy as sa
 from sqlalchemy.orm.attributes import get_history
+from sqlalchemy_utils.functions import naturally_equivalent
 
 
 def history_table(table):
@@ -51,29 +53,12 @@ def is_versioned(obj):
     )
 
 
-def has_changes(obj, attr):
+def versioned_column_properties(obj):
     """
-    Simple shortcut function for checking if given attribute of given
-    declarative model object has changed during the transaction.
+    Returns all versioned column properties for given versioned SQLAlchemy
+    declarative model object.
 
     :param obj: SQLAlchemy declarative model object
-    :param attr: Name of the attribute
-    """
-    return (
-        sa.inspect(obj)
-        .attrs
-        .get(attr)
-        .history
-        .has_changes()
-    )
-
-
-def is_modified(obj):
-    """
-    Returns whether or not the versioned properties of given object have been
-    modified.
-
-    :param obj: SQLAlchemy declarative model object.
     """
     manager = obj.__versioned__['manager']
 
@@ -82,9 +67,60 @@ def is_modified(obj):
             isinstance(prop, sa.orm.ColumnProperty) and
             not manager.is_excluded_column(obj, prop.columns[0])
         ):
-            attr = getattr(obj._sa_instance_state.attrs, prop.key)
-            if attr.history.has_changes():
-                return True
+            yield prop
+
+
+def vacuum(session, model):
+    """
+    When making structural changes to history tables (for example dropping
+    columns) there are sometimes situations where some old history records
+    become futile.
+
+    Vacuum deletes all futile history rows which had no changes compared to
+    previous version.
+
+
+    ::
+
+
+        from sqlalchemy_continuum import vacuum
+
+
+        vacuum(session, User)  # vacuums user history
+
+
+    :param session: SQLAlchemy session object
+    :param model: SQLAlchemy declarative model class
+    """
+    history_class = model.__versioned__['class']
+    manager = model.__versioned__['manager']
+    versions = defaultdict(list)
+
+    query = (
+        session.query(history_class)
+        .order_by(manager.option(history_class, 'transaction_column_name'))
+    )
+
+    for version in query:
+        if versions[version.id]:
+            prev_version = versions[version.id][-1]
+            if naturally_equivalent(prev_version, version):
+                session.delete(version)
+        else:
+            versions[version.id].append(version)
+
+
+def is_modified(obj):
+    """
+    Returns whether or not the versioned properties of given object have been
+    modified.
+
+    :param obj: SQLAlchemy declarative model object
+    """
+    for prop in versioned_column_properties(obj):
+        attr = getattr(sa.inspect(obj).attrs, prop.key)
+        if attr.history.has_changes():
+            return True
     return False
 
 
@@ -92,24 +128,24 @@ def changeset(obj):
     """
     Returns a humanized changeset for given SQLAlchemy declarative object.
 
-    :param obj: SQLAlchemy declarative model object.
+    :param obj: SQLAlchemy declarative model object
     """
     data = {}
     session = sa.orm.object_session(obj)
     if session and obj in session.deleted:
-        for attr in obj.__mapper__.class_manager.values():
-            if isinstance(attr.property, sa.orm.ColumnProperty):
-                if not attr.property.columns[0].primary_key:
-                    value = getattr(obj, attr.key)
+        for prop in obj.__mapper__.iterate_properties:
+            if isinstance(prop, sa.orm.ColumnProperty):
+                if not prop.columns[0].primary_key:
+                    value = getattr(obj, prop.key)
                     if value is not None:
-                        data[attr.key] = [None, getattr(obj, attr.key)]
+                        data[prop.key] = [None, getattr(obj, prop.key)]
     else:
-        for attr in obj.__mapper__.class_manager.values():
-            history = get_history(obj, attr.key)
+        for prop in obj.__mapper__.iterate_properties:
+            history = get_history(obj, prop.key)
             if history.has_changes():
                 old_value = history.deleted[0] if history.deleted else None
                 new_value = history.added[0] if history.added else None
 
                 if new_value:
-                    data[attr.key] = [new_value, old_value]
+                    data[prop.key] = [new_value, old_value]
     return data
