@@ -1,3 +1,5 @@
+from copy import copy
+import warnings
 import sqlalchemy as sa
 from sqlalchemy import create_engine
 from sqlalchemy.ext.declarative import declarative_base
@@ -8,7 +10,10 @@ from sqlalchemy_continuum.ext.flask import (
 )
 
 
-make_versioned()
+warnings.simplefilter('error', sa.exc.SAWarning)
+
+
+make_versioned(options={'strategy': 'subquery'})
 
 
 class QueryPool(object):
@@ -28,6 +33,21 @@ def log_sql(
 
 
 class TestCase(object):
+    versioning_strategy = 'subquery'
+    transaction_column_name = 'transaction_id'
+    end_transaction_column_name = 'end_transaction_id'
+    store_data_at_delete = False
+
+    @property
+    def options(self):
+        return {
+            'base_classes': (self.Model, ),
+            'strategy': self.versioning_strategy,
+            'transaction_column_name': self.transaction_column_name,
+            'end_transaction_column_name': self.end_transaction_column_name,
+            'store_data_at_delete': self.store_data_at_delete
+        }
+
     def setup_class(cls):
         versioning_manager.options['versioning'] = True
         flask_versioning_manager.options['versioning'] = False
@@ -46,6 +66,7 @@ class TestCase(object):
         self.create_models()
 
         sa.orm.configure_mappers()
+
         if hasattr(self, 'Article'):
             self.ArticleHistory = self.Article.__versioned__['class']
         if hasattr(self, 'Tag'):
@@ -78,9 +99,7 @@ class TestCase(object):
     def create_models(self):
         class Article(self.Model):
             __tablename__ = 'article'
-            __versioned__ = {
-                'base_classes': (self.Model, )
-            }
+            __versioned__ = copy(self.options)
 
             id = sa.Column(sa.Integer, autoincrement=True, primary_key=True)
             name = sa.Column(sa.Unicode(255), nullable=False)
@@ -89,9 +108,7 @@ class TestCase(object):
 
         class Tag(self.Model):
             __tablename__ = 'tag'
-            __versioned__ = {
-                'base_classes': (self.Model, )
-            }
+            __versioned__ = copy(self.options)
 
             id = sa.Column(sa.Integer, autoincrement=True, primary_key=True)
             name = sa.Column(sa.Unicode(255))
