@@ -1,7 +1,7 @@
 from tests import TestCase
 
 
-class TestVersionModelAccessors(TestCase):
+class VersionModelAccessorsTestCase(TestCase):
     def test_previous_for_first_version(self):
         article = self.Article()
         article.name = u'Some article'
@@ -39,6 +39,22 @@ class TestVersionModelAccessors(TestCase):
         ).all()
         assert versions[1].previous.name == u'Some article'
 
+    def test_previous_chaining(self):
+        article = self.Article()
+        article.name = u'Some article'
+        article.content = u'Some content'
+        self.session.add(article)
+        self.session.commit()
+        article.name = u'Updated article'
+        self.session.commit()
+        self.session.delete(article)
+        self.session.commit()
+        version = (
+            self.session.query(self.ArticleHistory)
+            .order_by(self.ArticleHistory.id)
+        ).all()[-1]
+        assert version.previous.previous
+
     def test_next_for_last_version(self):
         article = self.Article()
         article.name = u'Some article'
@@ -74,6 +90,22 @@ class TestVersionModelAccessors(TestCase):
 
         assert version.next
 
+    def test_chaining_next(self):
+        article = self.Article()
+        article.name = u'Some article'
+        article.content = u'Some content'
+        self.session.add(article)
+        self.session.commit()
+        article.name = u'Updated article'
+        self.session.commit()
+        article.content = u'Updated content'
+        self.session.commit()
+
+        versions = article.versions.all()
+        version = versions[0]
+        assert version.next == versions[1]
+        assert version.next.next == versions[2]
+
     def test_index_for_deleted_parent(self):
         article = self.Article()
         article.name = u'Some article'
@@ -99,3 +131,11 @@ class TestVersionModelAccessors(TestCase):
         self.session.commit()
 
         assert article.versions[0].index == 0
+
+
+class TestAccessorsWithSubqueryStrategy(VersionModelAccessorsTestCase):
+    versioning_strategy = 'subquery'
+
+
+class TestAccessorsWithValidityStrategy(VersionModelAccessorsTestCase):
+    versioning_strategy = 'validity'
